aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/pet_control/pet_section.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/titanic/pet_control/pet_section.h')
-rw-r--r--engines/titanic/pet_control/pet_section.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/titanic/pet_control/pet_section.h b/engines/titanic/pet_control/pet_section.h
index 43ae623b37..606aac182d 100644
--- a/engines/titanic/pet_control/pet_section.h
+++ b/engines/titanic/pet_control/pet_section.h
@@ -60,9 +60,9 @@ public:
virtual bool setup(CPetControl *petControl) { return false; }
/**
* Sets up the section
*/
- virtual bool setup() { return false; }
+ virtual bool reset() { return false; }
/**
* Draw the section
@@ -60,9 +60,9 @@ public:
virtual bool setup(CPetControl *petControl) { return false; }
/**
- * Sets up the section
+ * Reset the section
*/